@@ -1,4 +1,4 @@
-/* $Id: files.c,v 1.101 2001/03/18 18:55:06 astyanax Exp $ */
+/* $Id: files.c,v 1.105 2001/04/03 14:26:35 astyanax Exp $ */
 /**************************************************************************
  *   files.c                                                              *
  *                                                                        *
@@ -318,7 +318,7 @@ int do_insertfile(void)
  * we don't set the global variable filename to it's name, and don't
  * print out how many lines we wrote on the statusbar.
  * 
- * tmp means we are writing a tmp file in a secute fashion.  We use
+ * tmp means we are writing a tmp file in a secure fashion.  We use
  * it when spell checking or dumping the file on an error.
  */
 int write_file(char *name, int tmp)
@@ -736,7 +736,13 @@ char **cwd_tab_completion(char *buf, int *num_matches)
 	dirName[tmp - buf] = 0;
 
     } else {
+
+#ifdef PATH_MAX
+	if ((dirName = getcwd(NULL, PATH_MAX+1)) == NULL)
+#else
+	/* The better, but aparently segfault-causing way */
 	if ((dirName = getcwd(NULL, 0)) == NULL)
+#endif /* PATH_MAX */
 	    return matches;
 	else
 	    tmp = buf;
@@ -993,7 +999,7 @@ char *input_tab(char *buf, int place, int *lastWasTab, int *newplace)
 struct stat filestat(const char *path) {
     struct stat st;
 
-    lstat(path, &st);
+    stat(path, &st);
     return st;
 }
 
@@ -1003,26 +1009,20 @@ struct stat filestat(const char *path) {
 int diralphasort(const void *va, const void *vb) {
     struct stat file1info, file2info;
     char *a = *(char **)va, *b = *(char **)vb;
-    int answer = 0;
+    int aisdir, bisdir;
 
-    if (stat(a, &file1info) == -1)
-	answer = 1;
-    else if (stat(b, &file2info) == -1)
-	answer = 1;
-    else {
-	/* If is a is a dir and b isn't, return -1.
-	   Else if b is a dir and a isn't, return 0.
-	   Else return a < b */
+    aisdir = (stat(a, &file1info) != -1) && S_ISDIR(file1info.st_mode);
+    bisdir = (stat(b, &file2info) != -1) && S_ISDIR(file2info.st_mode);
 
-	if (S_ISDIR(file1info.st_mode) && !S_ISDIR(file2info.st_mode))
-	    return -1;
-	else if (!S_ISDIR(file1info.st_mode) && S_ISDIR(file2info.st_mode))
-	    return 1;
-	else
-	    answer = strcmp(a, b);
-    }
+    if (aisdir && !bisdir) return -1;
+    if (!aisdir && bisdir) return 1;
+
+#ifdef HAVE_STRCASECMP
+    return(strcasecmp(a,b));
+#else
+    return(strcmp(a,b));
+#endif
 
-    return(answer);
 }
 
 
@@ -1289,20 +1289,33 @@ char *do_browser(char *inpath)
 	    col += strlen(foo);
 
 	    /* Put file info in the string also */
-	    st = filestat(filelist[j]);
+	    /* We use lstat here to detect links, then if we find a
+		symlink we examine it via stat() to see if it is a
+		directory or just a file symlink */
+	    lstat(filelist[j], &st);
 	    if (S_ISDIR(st.st_mode))
 		strcpy(foo + longest - 5, "(dir)");
 	    else {
-		if (S_ISLNK(st.st_mode))
-		    strcpy(foo + longest - 2, "--");
-		else if (st.st_size < 1024) /* less than 1 K */
-		    sprintf(foo + longest - 7, "%4d  B", (int) st.st_size);
-		else if (st.st_size > 1073741824) /* at least 1 gig */
-		    sprintf(foo + longest - 7, "%4d GB", (int) st.st_size / 1073741824);
-		else if (st.st_size > 1048576) /* at least 1 meg */
-		    sprintf(foo + longest - 7, "%4d MB", (int) st.st_size / 1048576);
+		if (S_ISLNK(st.st_mode)) {
+		     /* Aha!  It's a symlink!  Now, is it a dir?  If so,
+			mark it as such */
+		    st = filestat(filelist[j]);
+		    if (S_ISDIR(st.st_mode))
+			strcpy(foo + longest - 5, "(dir)");
+		    else
+			strcpy(foo + longest - 2, "--");
+		} else if (st.st_size < (1 << 10)) /* less than 1 K */
+		    sprintf(foo + longest - 7, "%4d  B", 
+			(int) st.st_size >> 10);
+		else if (st.st_size >= (1 << 30)) /* at least 1 gig */
+		    sprintf(foo + longest - 7, "%4d GB", 
+			(int) st.st_size >> 30);
+		else if (st.st_size >= (1 << 20)) /* at least 1 meg */
+		    sprintf(foo + longest - 7, "%4d MB", 
+			(int) st.st_size >>     20);
 		else /* Its more than 1 k and less than a meg */
-		    sprintf(foo + longest - 7, "%4d KB", (int) st.st_size / 1024);
+		    sprintf(foo + longest - 7, "%4d KB", 
+			(int) st.st_size >> 10);
 	    }
 
 	    /* Hilight the currently selected file/dir */
@@ -1340,7 +1353,7 @@ char *do_browser(char *inpath)
     return retval;
 }
 
-/* Browser fron't end, checks to see if inpath has a dir in it and if so
+/* Browser front end, checks to see if inpath has a dir in it and if so
  starts do_browser from there, else from the current dir */
 char *do_browse_from(char *inpath)
 {
@@ -1349,9 +1362,16 @@ char *do_browse_from(char *inpath)
 
     tmp = mallocstrcpy(tmp, inpath);
 
+
     /* If there's no / in the string, we may was well start from . */
-    if (tmp == NULL || !strstr(tmp, "/"))
-	return do_browser(getcwd(NULL, 0));
+    if (tmp == NULL || *tmp == '\0' || !strstr(tmp, "/")) {
+#ifdef PATH_MAX
+	char *from = getcwd(NULL, PATH_MAX+1);
+#else
+	char *from = getcwd(NULL, 0);
+#endif /* PATH_MAX */
+	return do_browser(from ? from : "./");
+    }
 
     /* If the string is a directory, pass do_browser that */
     st = filestat(tmp);
