@@ -1,4 +1,4 @@
-/* $Id: proto.h,v 1.29 2000/11/29 04:33:26 astyanax Exp $ */
+/* $Id: proto.h,v 1.45 2001/03/18 16:59:34 astyanax Exp $ */
 /**************************************************************************
  *   proto.h                                                              *
  *                                                                        *
@@ -29,7 +29,7 @@
 
 #include "nano.h"
 
-extern int center_x, center_y, editwinrows;
+extern int editwinrows;
 extern int current_x, current_y, posible_max, totlines;
 extern int placewewant;
 extern int mark_beginx, samelinewrap;
@@ -38,7 +38,7 @@ extern int fill, flags,tabsize;
 extern int search_last_line;
 
 extern WINDOW *edit, *topwin, *bottomwin;
-extern char filename[PATH_MAX];
+extern char *filename;
 extern char *answer;
 extern char *hblank, *help_text;
 extern char *last_search;
@@ -51,6 +51,9 @@ extern shortcut main_list[MAIN_LIST_LEN], whereis_list[WHEREIS_LIST_LEN];
 extern shortcut replace_list[REPLACE_LIST_LEN], goto_list[GOTO_LIST_LEN];
 extern shortcut writefile_list[WRITEFILE_LIST_LEN], help_list[HELP_LIST_LEN];
 extern shortcut spell_list[SPELL_LIST_LEN], replace_list_2[REPLACE_LIST_LEN];
+#ifndef DISABLE_BROWSER
+extern shortcut browser_list[BROWSER_LIST_LEN];
+#endif
 
 #ifdef HAVE_REGEX_H
 extern int use_regexp, regexp_compiled;
@@ -78,7 +81,7 @@ int do_uncut_text(void);
 int no_help(void);
 int renumber_all(void);
 int open_file(char *filename, int insert, int quiet);
-int do_writeout(int exiting);
+int do_writeout(char *path, int exiting);
 int do_gotoline(long defline);
 int do_replace_loop(char *prevanswer, filestruct *begin, int *beginx,
 			int wholewords, int *i);
@@ -109,23 +112,25 @@ void check_statblank(void);
 void update_line(filestruct * fileptr, int index);
 void fix_editbot(void);
 void statusbar(char *msg, ...);
-void titlebar(void);
+void blank_statusbar(void);
+void titlebar(char *path);
 void previous_line(void);
 void center_cursor(void);
 void bottombars(shortcut s[], int slen);
 void blank_statusbar_refresh(void);
 void *nmalloc (size_t howmuch);
-void *mallocstrcpy(void *dest, void *src);
+void *mallocstrcpy(char *dest, char *src);
 void wrap_reset(void);
 void display_main_list(void);
 void nano_small_msg(void);
+void nano_disable_msg(void);
 void do_early_abort(void);
 void *nmalloc(size_t howmuch);
 void *nrealloc(void *ptr, size_t howmuch);
 void die(char *msg, ...);
 void new_file(void);
 void new_magicline(void);
-void splice_node(filestruct *begin, filestruct *new, filestruct *end);
+void splice_node(filestruct *begin, filestruct *newnode, filestruct *end);
 void null_at(char *data, int index);
 void page_up_center(void);
 void blank_edit(void);
@@ -133,6 +138,8 @@ void search_init_globals(void);
 void replace_abort(void);
 void add_to_cutbuffer(filestruct * inptr);
 void do_replace_highlight(int highlight_flag, char *word);
+void nano_disabled_msg(void);
+void window_init(void);
 #ifdef NANO_EXTRA
 void do_credits(void);
 #endif
@@ -145,6 +152,15 @@ int do_home(void), do_end(void), total_refresh(void), do_mark(void);
 int do_delete(void), do_backspace(void), do_tab(void), do_justify(void);
 int do_first_line(void), do_last_line(void);
 int do_replace(void), do_help(void), do_enter_void(void);
+int keypad_on(WINDOW * win, int newval);
+
+#ifndef DISABLE_BROWSER
+char *do_browser(char *path);
+struct stat filestat(const char *path);
+char *do_browse_from(char *inpath);
+#endif
+
+RETSIGTYPE main_loop (int junk);
 
 filestruct *copy_node(filestruct * src);
 filestruct *copy_filestruct(filestruct * src);
