@@ -1,4 +1,4 @@
-/* $Id: search.c,v 1.51 2000/12/05 11:36:41 astyanax Exp $ */
+/* $Id: search.c,v 1.56 2001/03/18 18:55:06 astyanax Exp $ */
 /**************************************************************************
  *   search.c                                                             *
  *                                                                        *
@@ -44,7 +44,7 @@ void regexp_init(const char *regexp)
     SET(REGEXP_COMPILED);
 }
 
-void regexp_cleanup()
+void regexp_cleanup(void)
 {
     UNSET(REGEXP_COMPILED);
     regfree(&search_regexp);
@@ -81,7 +81,6 @@ int search_init(int replacing)
     buf = nmalloc(strlen(last_search) + 5);
     buf[0] = 0;
 
-
      /* Okay, fun time.  backupstring is our holder for what is being 
 	returned from the statusq call.  Using answer for this would be tricky.
 	Here, if we're using PICO_MODE, we only want nano to put the
@@ -140,8 +139,14 @@ int search_init(int replacing)
 	return -1;
     } else if (i == -2) {	/* Same string */
 #ifdef HAVE_REGEX_H
-	if (ISSET(USE_REGEXP))
-	    regexp_init(answer);
+	if (ISSET(USE_REGEXP)) {
+
+	    /* If we're in pico mode, answer is "", use last_search! */
+	    if (ISSET(PICO_MODE))
+		regexp_init(last_search);
+	    else
+		regexp_init(answer);
+	}
 #else
 	;
 #endif
@@ -340,9 +345,9 @@ int do_search(void)
 void print_replaced(int num)
 {
     if (num > 1)
-	statusbar(_("Replaced %d occurences"), num);
+	statusbar(_("Replaced %d occurrences"), num);
     else if (num == 1)
-	statusbar(_("Replaced 1 occurence"));
+	statusbar(_("Replaced 1 occurrence"));
 }
 
 void replace_abort(void)
